@@ -1,4 +1,3 @@
-# -*- coding:utf-8 -*-
 #
 # Copyright 2020, Xiaomi.
 # All rights reserved.
@@ -9,9 +8,9 @@ from talos.consumer.MessageReader import MessageReader
 from talos.thrift.consumer.ttypes import QueryOffsetRequest
 from talos.thrift.consumer.ttypes import CheckPoint
 from talos.thrift.consumer.ttypes import UpdateOffsetRequest
-from talos.thrift.message.ttypes import GetPartitionOffsetRequest
 from talos.consumer.MessageCheckpointer import MessageCheckpointer
 from talos.utils import Utils
+from talos.thrift.common.ttypes import GalaxyTalosException
 import traceback
 import logging
 import time
@@ -24,38 +23,23 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
         MessageReader.__init__(self, consumerConfig)
 
     def init_start_offset(self):
-        # get last commit offset or init by outer checkPoint
-        readingStartOffset = int
-        # when consumer  starting up, checking:
+        # get last commit offset or init by outer checkPoint long readingStartOffset
+        if self.outerCheckPoint and self.outerCheckPoint >= 0:
+            readingStartOffset = self.outerCheckPoint
+            # burn after reading the first time
+            outerCheckPoint = None
+        else:
+            readingStartOffset = self.query_start_offset()
+
+        # when consumer starting up, checking:
         # 1) whether not exist last commit offset, which means 'readingStartOffset==-1'
         # 2) whether reset offset
         # 3) note that: the priority of 'reset-config' is larger than 'outer-checkPoint'
-
-        # there are following situations
-        # 1) reset Offset When Start
-        #    1) -1 ———— > set startOffset to - 1 and reading from start
-        #    2) -2 ———— > set startOffset to endOffset and reading from end
-        # 2) not reset Offset When Start
-        #    1) outerCheckPoint is set ———— > reading from outerCheckPoint
-        #    2) check point is not exist ———— > same with "1) reset Offset When Start"
-        #    3) check point is exist ———— > reading from check point
-
-        if self.consumerConfig.is_reset_offset_when_start():
-            readingStartOffset = self.reset_read_start_offset(
-                self.consumerConfig.get_reset_offset_value_when_start())
-        elif self.outerCheckPoint and self.outerCheckPoint >= 0:
-            readingStartOffset = self.outerCheckPoint
-            # burn after reading the first time
-            self.outerCheckPoint = None
+        if readingStartOffset == -1 or self.consumerConfig.is_reset_offset_when_start():
+            self.startOffset.get_and_set(self.consumerConfig.get_reset_offset_value_when_start())
         else:
-            queryStartOffset = self.query_start_offset()
-            if queryStartOffset == -1:
-                readingStartOffset = self.reset_read_start_offset(
-                    self.consumerConfig.get_reset_offset_value_when_start())
-            else:
-                readingStartOffset = queryStartOffset
+            self.startOffset.get_and_set(readingStartOffset)
 
-        self.startOffset.get_and_set(readingStartOffset)
         # guarantee lastCommitOffset and finishedOffset correct
         if self.startOffset.value > 0:
             self.lastCommitOffset = self.finishedOffset = self.startOffset.value - 1
@@ -65,16 +49,6 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
                          + str(self.topicAndPartition.partitionId))
         self.messageProcessor.init(self.topicAndPartition, self.startOffset.value)
 
-    def reset_read_start_offset(self, resetOffsetValueWhenStart=None):
-        # if resetOffsetValueWhenStart is -1 , just set startOffset to -1 and would read from the start
-        # if resetOffsetValueWhenStart is -2 , we should get the endOffset from the server for reading from the end
-        if resetOffsetValueWhenStart == -1:
-            return -1
-
-        request = GetPartitionOffsetRequest(self.topicAndPartition)
-        response = self.messageClient.get_partition_offset(request)
-        return response.endOffset + 1
-
     def commit_check_point(self):
         self.inner_checkpoint()
         self.messageProcessor.shutdown(self)
@@ -82,7 +56,6 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
     def fetch_data(self):
         # control fetch qps
         currentTime = Utils.current_time_mills()
-        # sleep time unit is seconds
         if currentTime - self.lastFetchTime < self.fetchInterval:
             time.sleep((self.lastFetchTime + self.fetchInterval - currentTime) / 1000)
 
@@ -109,6 +82,8 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
             self.startOffset.get_and_set(self.finishedOffset + 1)
             self.check_and_commit(True)
         except Exception as e:
+            if isinstance(e, GalaxyTalosException):
+                self.logger.error(e.errMsg)
             self.logger.error("Error when getting messages from topic: "
                               + self.topicAndPartition.topicTalosResourceName.topicTalosResourceName
                               + " partition: " + str(self.topicAndPartition.partitionId)
@@ -118,7 +93,7 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
 
     def query_start_offset(self):
         queryOffsetRequest = QueryOffsetRequest(self.consumerGroup, self.topicAndPartition)
-        queryOffsetResponse = self.queryOffsetClient.query_offset(queryOffsetRequest)
+        queryOffsetResponse = self.consumerClient.query_offset(queryOffsetRequest)
 
         committedOffset = queryOffsetResponse.msgOffset
         # 'committedOffset == -1' means not exist last committed offset
@@ -153,9 +128,12 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
             self.commit_offset(messageOffset)
             return True
         except Exception as e:
+            if isinstance(e, GalaxyTalosException):
+                self.logger.error(e.errMsg)
             self.logger.error("Error when getting messages from topic: " +
                               self.topicAndPartition.topicTalosResourceName.topicTalosResourceName()
-                              + " partition: " + str(self.topicAndPartition.partitionId) + e.message)
+                              + " partition: " + str(self.topicAndPartition.partitionId)
+                              + str(traceback.format_exc()))
             return False
 
     def commit_offset(self, messageOffset=None):
@@ -186,6 +164,8 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
             try:
                 self.inner_checkpoint()
             except Exception as e:
+                if isinstance(e, GalaxyTalosException):
+                    self.logger.error(e.errMsg)
                 # when commitOffset failed, we just do nothing;
                 self.logger.error("commit offset error, we skip to it"
                                   + str(traceback.format_exc()))
@@ -210,8 +190,11 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
             self.commit_offset(commitOffset)
             return True
         except Exception as e:
+            if isinstance(e, GalaxyTalosException):
+                self.logger.error(e.errMsg)
             self.logger.error("Error when getting messages from topic: " +
                               self.topicAndPartition.topicTalosResourceName.topicTalosResourceName
-                              + " partition: " + str(self.topicAndPartition.partitionId), e)
+                              + " partition: " + str(self.topicAndPartition.partitionId)
+                              + str(traceback.format_exc()))
             return False
 
