@@ -62,7 +62,7 @@ class PartitionMessageQueue:
                         self.logger.error(e.errMsg)
                     self.logger.error("getUserMessageList for partition: " +
                                       str(self.partitionId) + " is interrupt when waiting: "
-                                      + str(traceback.format_exc()))
+                                      + traceback.format_exc())
 
         if self.logger.isEnabledFor(level=logging.DEBUG):
             self.logger.debug("getUserMessageList wake up for partition: "
@@ -88,7 +88,7 @@ class PartitionMessageQueue:
             self.logger.debug("Ready to put message batch: " + str(len(returnList)) +
                               " queue size: " + str(len(self.userMessageList))
                               + " and curBytes: " + str(self.curMessageBytes) +
-                              " for partition: " + str(self.partitionId))
+                              " for partition: " + str(len(self.partitionId)))
         return returnList
 
     @synchronized
@@ -103,10 +103,10 @@ class PartitionMessageQueue:
             return True
 
         # when there have at least one message and it has exist enough long time;
-        if len(self.userMessageList) > 0:
-            curBufferedTime = Utils.current_time_mills() - self.userMessageList[len(self.userMessageList) - 1].get_timestamp()
-            if curBufferedTime >= self.maxBufferedTime:
-                return True
+        if (Utils.current_time_mills() - self.userMessageList[len(self.userMessageList) - 1].get_timestamp()) \
+                >= self.maxBufferedTime and len(self.userMessageList) > 0:
+            return True
+
         return False
 
     #
@@ -116,7 +116,7 @@ class PartitionMessageQueue:
     @synchronized
     def get_wait_time(self):
         if len(self.userMessageList) <= 0:
-            return 3600
+            return 0
         time = (self.userMessageList[len(self.userMessageList) - 1].get_timestamp()
                 + self.maxBufferedTime - Utils.current_time_mills()) / 1000
         if time > 0:
