@@ -88,8 +88,6 @@ class MessageCallbackTask(threading.Thread):
 class PartitionSender:
     logger = logging.getLogger("PartitionSender")
 
-    lock = threading.Lock()
-
     def __init__(self, partitionId=None, topicName=None, topicTalosResourceName=None,
                  requestId=None, clientId=None, talosProducerConfig=None,
                  messageClient=None, userMessageCallback=None, messageCallbackExecutors=None,
@@ -197,9 +195,9 @@ class PartitionSender:
                                                                     self.userMessageCallback)
                 self.messageCallbackExecutors.start()
                 return True
-            except Exception as e:
-                if isinstance(e, GalaxyTalosException):
-                    self.logger.error(e.errMsg)
+            except Exception as ex:
+                if isinstance(ex, GalaxyTalosException):
+                    self.logger.error(ex.errMsg)
                 self.logger.error("retry put message failed. " + str(traceback.format_exc()))
 
             # 3. clear messageQueue when retry > 10 and partition buffer size > 10MB
